@@ -125,6 +125,9 @@ void stickynotes_applet_init(PanelApplet *panel_applet)
 
 	icon_theme = gnome_icon_theme_new ();
 	sticky_icon = gnome_icon_theme_lookup_icon (icon_theme, "stock_notes", 48, NULL, NULL);
+	/* Register size for icons */
+	gtk_icon_size_register ("stickynotes_icon_size", 8,8);
+	
 
 	if (sticky_icon) {
 		gnome_window_icon_set_default_from_file(sticky_icon);
@@ -166,7 +169,7 @@ void stickynotes_applet_init(PanelApplet *panel_applet)
 }
 
 /* Initialize Sticky Notes Icons */
-void stickynotes_applet_init_icons()
+void stickynotes_applet_init_icons(void)
 {
 	GtkIconFactory *icon_factory = gtk_icon_factory_new();
 
@@ -189,7 +192,7 @@ void stickynotes_applet_init_icons()
 	g_object_unref(G_OBJECT(icon_factory));
 }
 
-void stickynotes_applet_init_prefs()
+void stickynotes_applet_init_prefs(void)
 {
 	stickynotes->prefs = glade_xml_new(GLADE_PATH, "preferences_dialog", NULL);
 
@@ -280,6 +283,8 @@ StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
 
 	/* Add the applet icon */
 	gtk_container_add(GTK_CONTAINER(panel_applet), applet->w_image);
+	applet->panel_size = panel_applet_get_size (panel_applet);
+	applet->panel_orient = panel_applet_get_orient (panel_applet);
 	stickynotes_applet_update_icon(applet);
 
 	/* Add the popup menu */
@@ -307,7 +312,8 @@ StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
 	g_signal_connect(G_OBJECT(applet->w_applet), "focus-out-event", G_CALLBACK(applet_focus_cb), applet);
 	g_signal_connect(G_OBJECT(applet->w_applet), "enter-notify-event", G_CALLBACK(applet_cross_cb), applet);
 	g_signal_connect(G_OBJECT(applet->w_applet), "leave-notify-event", G_CALLBACK(applet_cross_cb), applet);
-	g_signal_connect(G_OBJECT(applet->w_applet), "change-size", G_CALLBACK(applet_change_size_cb), applet);
+	g_signal_connect(G_OBJECT(applet->w_applet), "size-allocate", G_CALLBACK(applet_size_allocate_cb), applet);
+	g_signal_connect(G_OBJECT(applet->w_applet), "change-orient", G_CALLBACK(applet_change_orient_cb), applet);
 	g_signal_connect(G_OBJECT(applet->w_applet), "change-background", G_CALLBACK(applet_change_bg_cb), applet);
 	g_signal_connect(G_OBJECT(applet->w_applet), "destroy", G_CALLBACK(applet_destroy_cb), applet);
 
@@ -324,7 +330,7 @@ void stickynotes_applet_update_icon(StickyNotesApplet *applet)
 {
 	GdkPixbuf *pixbuf1, *pixbuf2;
 
-	gint size = panel_applet_get_size(PANEL_APPLET(applet->w_applet));
+	gint size = applet->panel_size;
 
 	/* Choose appropriate icon and size it */
 	if (applet->prelighted)
@@ -344,7 +350,7 @@ void stickynotes_applet_update_icon(StickyNotesApplet *applet)
 	g_object_unref(pixbuf2);
 }
 
-void stickynotes_applet_update_prefs()
+void stickynotes_applet_update_prefs(void)
 {
 	gint height, click_behavior;
 	gboolean sys_color, sys_font, sticky, force_default;
@@ -395,7 +401,7 @@ void stickynotes_applet_update_prefs()
 	}
 }
 
-void stickynotes_applet_update_menus()
+void stickynotes_applet_update_menus(void)
 {
 	gboolean visible = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/visible", NULL);
 	gboolean locked = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/locked", NULL);
@@ -427,7 +433,7 @@ void stickynotes_applet_update_menus()
 	}
 }
 
-void stickynotes_applet_update_tooltips()
+void stickynotes_applet_update_tooltips(void)
 {
 	gint num = g_list_length(stickynotes->notes);
 	gchar *tooltip = g_strdup_printf(ngettext("%s\n%d note", "%s\n%d notes", num), _("Sticky Notes"), num);
